# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# Analytics Game Telemetry (1.9.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.gametelemetry.models import HTTPValidationError
from ..api.gametelemetry.models import TelemetryBody
from ..api.gametelemetry.models import ValidationError


def create_http_validation_error_example() -> HTTPValidationError:
    instance = HTTPValidationError()
    instance.detail = [create_validation_error_example()]
    return instance


def create_telemetry_body_example() -> TelemetryBody:
    instance = TelemetryBody()
    instance.event_name = randomize()
    instance.event_namespace = randomize("slug")
    instance.payload = {randomize(): randomize()}
    instance.event_id = randomize()
    instance.event_timestamp = randomize("date")
    return instance


def create_validation_error_example() -> ValidationError:
    instance = ValidationError()
    instance.loc = [randomize()]
    instance.msg = randomize()
    instance.type_ = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Iam Service."""

__version__ = "5.16.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# bans
from .wrappers import admin_ban_user_bulk_v3
from .wrappers import admin_ban_user_bulk_v3_async
from .wrappers import admin_get_banned_users_v3
from .wrappers import admin_get_banned_users_v3_async
from .wrappers import admin_get_bans_type_v3
from .wrappers import admin_get_bans_type_v3_async
from .wrappers import admin_get_bans_type_with_namespace_v3
from .wrappers import admin_get_bans_type_with_namespace_v3_async
from .wrappers import admin_get_list_ban_reason_v3
from .wrappers import admin_get_list_ban_reason_v3_async
from .wrappers import admin_unban_user_bulk_v3
from .wrappers import admin_unban_user_bulk_v3_async
from .wrappers import get_bans_type
from .wrappers import get_bans_type_async
from .wrappers import get_list_ban_reason
from .wrappers import get_list_ban_reason_async

# clients
from .wrappers import add_client_permission
from .wrappers import add_client_permission_async
from .wrappers import admin_add_client_permissions_v3
from .wrappers import admin_add_client_permissions_v3_async
from .wrappers import admin_create_client_v3
from .wrappers import admin_create_client_v3_async
from .wrappers import admin_delete_client_permission_v3
from .wrappers import admin_delete_client_permission_v3_async
from .wrappers import admin_delete_client_v3
from .wrappers import admin_delete_client_v3_async
from .wrappers import admin_get_clients_by_namespace_v3
from .wrappers import admin_get_clients_by_namespace_v3_async
from .wrappers import admin_get_clientsby_namespaceby_idv3
from .wrappers import admin_get_clientsby_namespaceby_idv3_async
from .wrappers import admin_update_client_permission_v3
from .wrappers import admin_update_client_permission_v3_async
from .wrappers import admin_update_client_secret_v3
from .wrappers import admin_update_client_secret_v3_async
from .wrappers import admin_update_client_v3
from .wrappers import admin_update_client_v3_async
from .wrappers import create_client
from .wrappers import create_client_async
from .wrappers import create_client_by_namespace
from .wrappers import create_client_by_namespace_async
from .wrappers import delete_client
from .wrappers import delete_client_async
from .wrappers import delete_client_by_namespace
from .wrappers import delete_client_by_namespace_async
from .wrappers import delete_client_permission
from .wrappers import delete_client_permission_async
from .wrappers import get_client
from .wrappers import get_client_async
from .wrappers import get_clients
from .wrappers import get_clients_async
from .wrappers import get_clientsby_namespace
from .wrappers import get_clientsby_namespace_async
from .wrappers import update_client
from .wrappers import update_client_async
from .wrappers import update_client_permission
from .wrappers import update_client_permission_async
from .wrappers import update_client_secret
from .wrappers import update_client_secret_async

# input_validations
from .wrappers import admin_get_input_validations
from .wrappers import admin_get_input_validations_async
from .wrappers import admin_reset_input_validations
from .wrappers import admin_reset_input_validations_async
from .wrappers import admin_update_input_validations
from .wrappers import admin_update_input_validations_async
from .wrappers import public_get_input_validations
from .wrappers import public_get_input_validations_async

# o_auth
from .wrappers import authorization
from .wrappers import authorization_async
from .wrappers import get_jwks
from .wrappers import get_jwks_async
from .wrappers import get_revocation_list
from .wrappers import get_revocation_list_async
from .wrappers import platform_token_request_handler
from .wrappers import platform_token_request_handler_async
from .wrappers import revoke_a_user
from .wrappers import revoke_a_user_async
from .wrappers import revoke_token
from .wrappers import revoke_token_async
from .wrappers import revoke_user
from .wrappers import revoke_user_async
from .wrappers import token_grant
from .wrappers import token_grant_async
from .wrappers import verify_token
from .wrappers import verify_token_async

# o_auth2_0
from .wrappers import admin_retrieve_user_third_party_platform_token_v3
from .wrappers import admin_retrieve_user_third_party_platform_token_v3_async
from .wrappers import auth_code_request_v3
from .wrappers import auth_code_request_v3_async
from .wrappers import authorize_v3
from .wrappers import authorize_v3_async
from .wrappers import change2fa_method
from .wrappers import change2fa_method_async
from .wrappers import get_jwksv3
from .wrappers import get_jwksv3_async
from .wrappers import get_revocation_list_v3
from .wrappers import get_revocation_list_v3_async
from .wrappers import platform_token_grant_v3
from .wrappers import platform_token_grant_v3_async
from .wrappers import retrieve_user_third_party_platform_token_v3
from .wrappers import retrieve_user_third_party_platform_token_v3_async
from .wrappers import revoke_user_v3
from .wrappers import revoke_user_v3_async
from .wrappers import token_grant_v3
from .wrappers import token_grant_v3_async
from .wrappers import token_introspection_v3
from .wrappers import token_introspection_v3_async
from .wrappers import token_revocation_v3
from .wrappers import token_revocation_v3_async
from .wrappers import verify2fa_code
from .wrappers import verify2fa_code_async
from .wrappers import verify_token_v3
from .wrappers import verify_token_v3_async

# o_auth2_0_extension
from .wrappers import authentication_with_platform_link_v3
from .wrappers import authentication_with_platform_link_v3_async
from .wrappers import generate_token_by_new_headless_account_v3
from .wrappers import generate_token_by_new_headless_account_v3_async
from .wrappers import get_country_location_v3
from .wrappers import get_country_location_v3_async
from .wrappers import logout
from .wrappers import logout_async
from .wrappers import platform_authentication_v3
from .wrappers import platform_authentication_v3_async
from .wrappers import request_game_token_code_response_v3
from .wrappers import request_game_token_code_response_v3_async
from .wrappers import request_game_token_response_v3
from .wrappers import request_game_token_response_v3_async
from .wrappers import user_authentication_v3
from .wrappers import user_authentication_v3_async

# roles
from .wrappers import add_role_managers
from .wrappers import add_role_managers_async
from .wrappers import add_role_members
from .wrappers import add_role_members_async
from .wrappers import add_role_permission
from .wrappers import add_role_permission_async
from .wrappers import admin_add_role_managers_v3
from .wrappers import admin_add_role_managers_v3_async
from .wrappers import admin_add_role_members_v3
from .wrappers import admin_add_role_members_v3_async
from .wrappers import admin_add_role_permissions_v3
from .wrappers import admin_add_role_permissions_v3_async
from .wrappers import admin_add_role_permissions_v4
from .wrappers import admin_add_role_permissions_v4_async
from .wrappers import admin_assign_user_to_role_v4
from .wrappers import admin_assign_user_to_role_v4_async
from .wrappers import admin_create_role_v3
from .wrappers import admin_create_role_v3_async
from .wrappers import admin_create_role_v4
from .wrappers import admin_create_role_v4_async
from .wrappers import admin_delete_role_permission_v3
from .wrappers import admin_delete_role_permission_v3_async
from .wrappers import admin_delete_role_permissions_v3
from .wrappers import admin_delete_role_permissions_v3_async
from .wrappers import admin_delete_role_permissions_v4
from .wrappers import admin_delete_role_permissions_v4_async
from .wrappers import admin_delete_role_v3
from .wrappers import admin_delete_role_v3_async
from .wrappers import admin_delete_role_v4
from .wrappers import admin_delete_role_v4_async
from .wrappers import admin_get_role_admin_status_v3
from .wrappers import admin_get_role_admin_status_v3_async
from .wrappers import admin_get_role_managers_v3
from .wrappers import admin_get_role_managers_v3_async
from .wrappers import admin_get_role_members_v3
from .wrappers import admin_get_role_members_v3_async
from .wrappers import admin_get_role_v3
from .wrappers import admin_get_role_v3_async
from .wrappers import admin_get_role_v4
from .wrappers import admin_get_role_v4_async
from .wrappers import admin_get_roles_v3
from .wrappers import admin_get_roles_v3_async
from .wrappers import admin_get_roles_v4
from .wrappers import admin_get_roles_v4_async
from .wrappers import admin_list_assigned_users_v4
from .wrappers import admin_list_assigned_users_v4_async
from .wrappers import admin_remove_role_admin_v3
from .wrappers import admin_remove_role_admin_v3_async
from .wrappers import admin_remove_role_managers_v3
from .wrappers import admin_remove_role_managers_v3_async
from .wrappers import admin_remove_role_members_v3
from .wrappers import admin_remove_role_members_v3_async
from .wrappers import admin_revoke_user_from_role_v4
from .wrappers import admin_revoke_user_from_role_v4_async
from .wrappers import admin_update_admin_role_status_v3
from .wrappers import admin_update_admin_role_status_v3_async
from .wrappers import admin_update_role_permissions_v3
from .wrappers import admin_update_role_permissions_v3_async
from .wrappers import admin_update_role_permissions_v4
from .wrappers import admin_update_role_permissions_v4_async
from .wrappers import admin_update_role_v3
from .wrappers import admin_update_role_v3_async
from .wrappers import admin_update_role_v4
from .wrappers import admin_update_role_v4_async
from .wrappers import create_role
from .wrappers import create_role_async
from .wrappers import delete_role
from .wrappers import delete_role_async
from .wrappers import delete_role_permission
from .wrappers import delete_role_permission_async
from .wrappers import get_role
from .wrappers import get_role_async
from .wrappers import get_role_admin_status
from .wrappers import get_role_admin_status_async
from .wrappers import get_role_managers
from .wrappers import get_role_managers_async
from .wrappers import get_role_members
from .wrappers import get_role_members_async
from .wrappers import get_roles
from .wrappers import get_roles_async
from .wrappers import public_get_role_v3
from .wrappers import public_get_role_v3_async
from .wrappers import public_get_roles_v3
from .wrappers import public_get_roles_v3_async
from .wrappers import remove_role_admin
from .wrappers import remove_role_admin_async
from .wrappers import remove_role_managers
from .wrappers import remove_role_managers_async
from .wrappers import remove_role_members
from .wrappers import remove_role_members_async
from .wrappers import set_role_as_admin
from .wrappers import set_role_as_admin_async
from .wrappers import update_role
from .wrappers import update_role_async
from .wrappers import update_role_permissions
from .wrappers import update_role_permissions_async

# sso
from .wrappers import login_sso_client
from .wrappers import login_sso_client_async
from .wrappers import logout_sso_client
from .wrappers import logout_sso_client_async

# sso_credential
from .wrappers import add_sso_login_platform_credential
from .wrappers import add_sso_login_platform_credential_async
from .wrappers import delete_sso_login_platform_credential_v3
from .wrappers import delete_sso_login_platform_credential_v3_async
from .wrappers import retrieve_all_sso_login_platform_credential_v3
from .wrappers import retrieve_all_sso_login_platform_credential_v3_async
from .wrappers import retrieve_sso_login_platform_credential
from .wrappers import retrieve_sso_login_platform_credential_async
from .wrappers import update_sso_platform_credential
from .wrappers import update_sso_platform_credential_async

# sso_saml_2_0
from .wrappers import platform_authenticate_samlv3_handler
from .wrappers import platform_authenticate_samlv3_handler_async

# third_party_credential
from .wrappers import add_third_party_login_platform_credential_v3
from .wrappers import add_third_party_login_platform_credential_v3_async
from .wrappers import delete_third_party_login_platform_credential_v3
from .wrappers import delete_third_party_login_platform_credential_v3_async
from .wrappers import delete_third_party_login_platform_domain_v3
from .wrappers import delete_third_party_login_platform_domain_v3_async
from .wrappers import retrieve_active_oidc_clients_public_v3
from .wrappers import retrieve_active_oidc_clients_public_v3_async
from .wrappers import (
    retrieve_all_active_third_party_login_platform_credential_public_v3,
)
from .wrappers import (
    retrieve_all_active_third_party_login_platform_credential_public_v3_async,
)
from .wrappers import retrieve_all_active_third_party_login_platform_credential_v3
from .wrappers import retrieve_all_active_third_party_login_platform_credential_v3_async
from .wrappers import retrieve_all_third_party_login_platform_credential_v3
from .wrappers import retrieve_all_third_party_login_platform_credential_v3_async
from .wrappers import retrieve_third_party_login_platform_credential_v3
from .wrappers import retrieve_third_party_login_platform_credential_v3_async
from .wrappers import update_third_party_login_platform_credential_v3
from .wrappers import update_third_party_login_platform_credential_v3_async
from .wrappers import update_third_party_login_platform_domain_v3
from .wrappers import update_third_party_login_platform_domain_v3_async

# users
from .wrappers import add_user_permission
from .wrappers import add_user_permission_async
from .wrappers import add_user_role
from .wrappers import add_user_role_async
from .wrappers import admin_add_user_permissions_v3
from .wrappers import admin_add_user_permissions_v3_async
from .wrappers import admin_add_user_role_v3
from .wrappers import admin_add_user_role_v3_async
from .wrappers import admin_ban_user_v2
from .wrappers import admin_ban_user_v2_async
from .wrappers import admin_ban_user_v3
from .wrappers import admin_ban_user_v3_async
from .wrappers import admin_create_justice_user
from .wrappers import admin_create_justice_user_async
from .wrappers import admin_create_user_roles_v2
from .wrappers import admin_create_user_roles_v2_async
from .wrappers import admin_delete_platform_link_v2
from .wrappers import admin_delete_platform_link_v2_async
from .wrappers import admin_delete_user_information_v3
from .wrappers import admin_delete_user_information_v3_async
from .wrappers import admin_delete_user_permission_bulk_v3
from .wrappers import admin_delete_user_permission_bulk_v3_async
from .wrappers import admin_delete_user_permission_v3
from .wrappers import admin_delete_user_permission_v3_async
from .wrappers import admin_delete_user_role_v3
from .wrappers import admin_delete_user_role_v3_async
from .wrappers import admin_delete_user_roles_v3
from .wrappers import admin_delete_user_roles_v3_async
from .wrappers import admin_disable_user_v2
from .wrappers import admin_disable_user_v2_async
from .wrappers import admin_enable_user_v2
from .wrappers import admin_enable_user_v2_async
from .wrappers import admin_get_age_restriction_status_v2
from .wrappers import admin_get_age_restriction_status_v2_async
from .wrappers import admin_get_age_restriction_status_v3
from .wrappers import admin_get_age_restriction_status_v3_async
from .wrappers import admin_get_bulk_user_by_email_address_v3
from .wrappers import admin_get_bulk_user_by_email_address_v3_async
from .wrappers import admin_get_list_country_age_restriction_v3
from .wrappers import admin_get_list_country_age_restriction_v3_async
from .wrappers import admin_get_list_justice_platform_accounts
from .wrappers import admin_get_list_justice_platform_accounts_async
from .wrappers import admin_get_my_user_v3
from .wrappers import admin_get_my_user_v3_async
from .wrappers import admin_get_user_ban_v2
from .wrappers import admin_get_user_ban_v2_async
from .wrappers import admin_get_user_ban_v3
from .wrappers import admin_get_user_ban_v3_async
from .wrappers import admin_get_user_by_email_address_v3
from .wrappers import admin_get_user_by_email_address_v3_async
from .wrappers import admin_get_user_by_platform_user_idv3
from .wrappers import admin_get_user_by_platform_user_idv3_async
from .wrappers import admin_get_user_by_user_id_v2
from .wrappers import admin_get_user_by_user_id_v2_async
from .wrappers import admin_get_user_by_user_id_v3
from .wrappers import admin_get_user_by_user_id_v3_async
from .wrappers import admin_get_user_deletion_status_v3
from .wrappers import admin_get_user_deletion_status_v3_async
from .wrappers import admin_get_user_login_histories_v3
from .wrappers import admin_get_user_login_histories_v3_async
from .wrappers import admin_get_user_mapping
from .wrappers import admin_get_user_mapping_async
from .wrappers import admin_get_user_platform_accounts_v3
from .wrappers import admin_get_user_platform_accounts_v3_async
from .wrappers import admin_invite_user_v3
from .wrappers import admin_invite_user_v3_async
from .wrappers import admin_link_platform_account
from .wrappers import admin_link_platform_account_async
from .wrappers import admin_list_user_id_by_user_i_ds_v3
from .wrappers import admin_list_user_id_by_user_i_ds_v3_async
from .wrappers import admin_list_users_v3
from .wrappers import admin_list_users_v3_async
from .wrappers import admin_platform_link_v3
from .wrappers import admin_platform_link_v3_async
from .wrappers import admin_platform_unlink_v3
from .wrappers import admin_platform_unlink_v3_async
from .wrappers import admin_put_user_roles_v2
from .wrappers import admin_put_user_roles_v2_async
from .wrappers import admin_reset_password_v2
from .wrappers import admin_reset_password_v2_async
from .wrappers import admin_reset_password_v3
from .wrappers import admin_reset_password_v3_async
from .wrappers import admin_save_user_role_v3
from .wrappers import admin_save_user_role_v3_async
from .wrappers import admin_search_user_v3
from .wrappers import admin_search_user_v3_async
from .wrappers import admin_search_users_v2
from .wrappers import admin_search_users_v2_async
from .wrappers import admin_send_verification_code_v3
from .wrappers import admin_send_verification_code_v3_async
from .wrappers import admin_update_age_restriction_config_v2
from .wrappers import admin_update_age_restriction_config_v2_async
from .wrappers import admin_update_age_restriction_config_v3
from .wrappers import admin_update_age_restriction_config_v3_async
from .wrappers import admin_update_country_age_restriction_v3
from .wrappers import admin_update_country_age_restriction_v3_async
from .wrappers import admin_update_user_ban_v3
from .wrappers import admin_update_user_ban_v3_async
from .wrappers import admin_update_user_deletion_status_v3
from .wrappers import admin_update_user_deletion_status_v3_async
from .wrappers import admin_update_user_permission_v3
from .wrappers import admin_update_user_permission_v3_async
from .wrappers import admin_update_user_status_v3
from .wrappers import admin_update_user_status_v3_async
from .wrappers import admin_update_user_v2
from .wrappers import admin_update_user_v2_async
from .wrappers import admin_update_user_v3
from .wrappers import admin_update_user_v3_async
from .wrappers import admin_upgrade_headless_account_v3
from .wrappers import admin_upgrade_headless_account_v3_async
from .wrappers import admin_verify_account_v3
from .wrappers import admin_verify_account_v3_async
from .wrappers import admin_verify_user_without_verification_code_v3
from .wrappers import admin_verify_user_without_verification_code_v3_async
from .wrappers import ban_user
from .wrappers import ban_user_async
from .wrappers import check_user_availability
from .wrappers import check_user_availability_async
from .wrappers import create_user
from .wrappers import create_user_async
from .wrappers import create_user_from_invitation_v3
from .wrappers import create_user_from_invitation_v3_async
from .wrappers import delete_user
from .wrappers import delete_user_async
from .wrappers import delete_user_information
from .wrappers import delete_user_information_async
from .wrappers import delete_user_permission
from .wrappers import delete_user_permission_async
from .wrappers import delete_user_role
from .wrappers import delete_user_role_async
from .wrappers import disable_user
from .wrappers import disable_user_async
from .wrappers import disable_user_ban
from .wrappers import disable_user_ban_async
from .wrappers import enable_user
from .wrappers import enable_user_async
from .wrappers import enable_user_ban
from .wrappers import enable_user_ban_async
from .wrappers import forgot_password
from .wrappers import forgot_password_async
from .wrappers import get_admin_invitation_v3
from .wrappers import get_admin_invitation_v3_async
from .wrappers import get_admin_users_by_role_id
from .wrappers import get_admin_users_by_role_id_async
from .wrappers import get_admin_users_by_role_id_v3
from .wrappers import get_admin_users_by_role_id_v3_async
from .wrappers import get_list_country_age_restriction
from .wrappers import get_list_country_age_restriction_async
from .wrappers import get_list_justice_platform_accounts
from .wrappers import get_list_justice_platform_accounts_async
from .wrappers import get_publisher_user
from .wrappers import get_publisher_user_async
from .wrappers import get_user_ban_history
from .wrappers import get_user_ban_history_async
from .wrappers import get_user_by_login_id
from .wrappers import get_user_by_login_id_async
from .wrappers import get_user_by_platform_user_id
from .wrappers import get_user_by_platform_user_id_async
from .wrappers import get_user_by_user_id
from .wrappers import get_user_by_user_id_async
from .wrappers import get_user_information
from .wrappers import get_user_information_async
from .wrappers import get_user_justice_platform_account
from .wrappers import get_user_justice_platform_account_async
from .wrappers import get_user_login_histories
from .wrappers import get_user_login_histories_async
from .wrappers import get_user_mapping
from .wrappers import get_user_mapping_async
from .wrappers import get_user_platform_accounts
from .wrappers import get_user_platform_accounts_async
from .wrappers import get_user_verification_code
from .wrappers import get_user_verification_code_async
from .wrappers import get_users_by_login_ids
from .wrappers import get_users_by_login_ids_async
from .wrappers import list_admins_v3
from .wrappers import list_admins_v3_async
from .wrappers import list_cross_namespace_account_link
from .wrappers import list_cross_namespace_account_link_async
from .wrappers import platform_link
from .wrappers import platform_link_async
from .wrappers import platform_unlink
from .wrappers import platform_unlink_async
from .wrappers import public_bulk_get_users
from .wrappers import public_bulk_get_users_async
from .wrappers import public_create_justice_user
from .wrappers import public_create_justice_user_async
from .wrappers import public_create_user_v2
from .wrappers import public_create_user_v2_async
from .wrappers import public_create_user_v3
from .wrappers import public_create_user_v3_async
from .wrappers import public_delete_platform_link_v2
from .wrappers import public_delete_platform_link_v2_async
from .wrappers import public_force_link_platform_with_progression
from .wrappers import public_force_link_platform_with_progression_async
from .wrappers import public_force_platform_link_v3
from .wrappers import public_force_platform_link_v3_async
from .wrappers import public_forgot_password_v2
from .wrappers import public_forgot_password_v2_async
from .wrappers import public_forgot_password_v3
from .wrappers import public_forgot_password_v3_async
from .wrappers import public_get_async_status
from .wrappers import public_get_async_status_async
from .wrappers import public_get_country_age_restriction
from .wrappers import public_get_country_age_restriction_async
from .wrappers import public_get_country_age_restriction_v3
from .wrappers import public_get_country_age_restriction_v3_async
from .wrappers import public_get_my_user_v3
from .wrappers import public_get_my_user_v3_async
from .wrappers import public_get_publisher_user_v3
from .wrappers import public_get_publisher_user_v3_async
from .wrappers import public_get_user_ban
from .wrappers import public_get_user_ban_async
from .wrappers import public_get_user_ban_history_v3
from .wrappers import public_get_user_ban_history_v3_async
from .wrappers import public_get_user_by_platform_user_idv3
from .wrappers import public_get_user_by_platform_user_idv3_async
from .wrappers import public_get_user_by_user_id_v3
from .wrappers import public_get_user_by_user_id_v3_async
from .wrappers import public_get_user_by_user_idv2
from .wrappers import public_get_user_by_user_idv2_async
from .wrappers import public_get_user_information_v3
from .wrappers import public_get_user_information_v3_async
from .wrappers import public_get_user_login_histories_v3
from .wrappers import public_get_user_login_histories_v3_async
from .wrappers import public_get_user_platform_accounts_v3
from .wrappers import public_get_user_platform_accounts_v3_async
from .wrappers import public_link_platform_account
from .wrappers import public_link_platform_account_async
from .wrappers import public_list_justice_platform_accounts_v3
from .wrappers import public_list_justice_platform_accounts_v3_async
from .wrappers import public_list_user_all_platform_accounts_distinct_v3
from .wrappers import public_list_user_all_platform_accounts_distinct_v3_async
from .wrappers import public_list_user_id_by_platform_user_i_ds_v3
from .wrappers import public_list_user_id_by_platform_user_i_ds_v3_async
from .wrappers import public_partial_update_user_v3
from .wrappers import public_partial_update_user_v3_async
from .wrappers import public_platform_link_v2
from .wrappers import public_platform_link_v2_async
from .wrappers import public_platform_link_v3
from .wrappers import public_platform_link_v3_async
from .wrappers import public_platform_unlink_all_v3
from .wrappers import public_platform_unlink_all_v3_async
from .wrappers import public_platform_unlink_v3
from .wrappers import public_platform_unlink_v3_async
from .wrappers import public_reset_password_v2
from .wrappers import public_reset_password_v2_async
from .wrappers import public_search_user_v3
from .wrappers import public_search_user_v3_async
from .wrappers import public_send_registration_code
from .wrappers import public_send_registration_code_async
from .wrappers import public_send_verification_code_v3
from .wrappers import public_send_verification_code_v3_async
from .wrappers import public_send_verification_link_v3
from .wrappers import public_send_verification_link_v3_async
from .wrappers import public_update_password_v2
from .wrappers import public_update_password_v2_async
from .wrappers import public_update_password_v3
from .wrappers import public_update_password_v3_async
from .wrappers import public_update_user_v2
from .wrappers import public_update_user_v2_async
from .wrappers import public_upgrade_headless_account_v3
from .wrappers import public_upgrade_headless_account_v3_async
from .wrappers import public_user_verification_v3
from .wrappers import public_user_verification_v3_async
from .wrappers import public_validate_user_by_user_id_and_password_v3
from .wrappers import public_validate_user_by_user_id_and_password_v3_async
from .wrappers import public_verify_headless_account_v3
from .wrappers import public_verify_headless_account_v3_async
from .wrappers import public_verify_registration_code
from .wrappers import public_verify_registration_code_async
from .wrappers import public_verify_user_by_link_v3
from .wrappers import public_verify_user_by_link_v3_async
from .wrappers import public_web_link_platform
from .wrappers import public_web_link_platform_async
from .wrappers import public_web_link_platform_establish
from .wrappers import public_web_link_platform_establish_async
from .wrappers import reset_password
from .wrappers import reset_password_async
from .wrappers import reset_password_v3
from .wrappers import reset_password_v3_async
from .wrappers import save_user_permission
from .wrappers import save_user_permission_async
from .wrappers import save_user_roles
from .wrappers import save_user_roles_async
from .wrappers import search_user
from .wrappers import search_user_async
from .wrappers import send_verification_code
from .wrappers import send_verification_code_async
from .wrappers import update_country_age_restriction
from .wrappers import update_country_age_restriction_async
from .wrappers import update_password
from .wrappers import update_password_async
from .wrappers import update_user
from .wrappers import update_user_async
from .wrappers import update_user_v3
from .wrappers import update_user_v3_async
from .wrappers import upgrade_headless_account
from .wrappers import upgrade_headless_account_async
from .wrappers import upgrade_headless_account_with_verification_code
from .wrappers import upgrade_headless_account_with_verification_code_async
from .wrappers import user_verification
from .wrappers import user_verification_async

# users_v4
from .wrappers import admin_add_user_role_v4
from .wrappers import admin_add_user_role_v4_async
from .wrappers import admin_bulk_check_valid_user_idv4
from .wrappers import admin_bulk_check_valid_user_idv4_async
from .wrappers import admin_create_test_users_v4
from .wrappers import admin_create_test_users_v4_async
from .wrappers import admin_disable_my_authenticator_v4
from .wrappers import admin_disable_my_authenticator_v4_async
from .wrappers import admin_disable_my_backup_codes_v4
from .wrappers import admin_disable_my_backup_codes_v4_async
from .wrappers import admin_disable_user_mfav4
from .wrappers import admin_disable_user_mfav4_async
from .wrappers import admin_download_my_backup_codes_v4
from .wrappers import admin_download_my_backup_codes_v4_async
from .wrappers import admin_enable_my_authenticator_v4
from .wrappers import admin_enable_my_authenticator_v4_async
from .wrappers import admin_enable_my_backup_codes_v4
from .wrappers import admin_enable_my_backup_codes_v4_async
from .wrappers import admin_generate_my_authenticator_key_v4
from .wrappers import admin_generate_my_authenticator_key_v4_async
from .wrappers import admin_generate_my_backup_codes_v4
from .wrappers import admin_generate_my_backup_codes_v4_async
from .wrappers import admin_get_my_backup_codes_v4
from .wrappers import admin_get_my_backup_codes_v4_async
from .wrappers import admin_get_my_enabled_factors_v4
from .wrappers import admin_get_my_enabled_factors_v4_async
from .wrappers import admin_invite_user_v4
from .wrappers import admin_invite_user_v4_async
from .wrappers import admin_list_user_roles_v4
from .wrappers import admin_list_user_roles_v4_async
from .wrappers import admin_make_factor_my_default_v4
from .wrappers import admin_make_factor_my_default_v4_async
from .wrappers import admin_remove_user_role_v4
from .wrappers import admin_remove_user_role_v4_async
from .wrappers import admin_update_my_user_v4
from .wrappers import admin_update_my_user_v4_async
from .wrappers import admin_update_user_email_address_v4
from .wrappers import admin_update_user_email_address_v4_async
from .wrappers import admin_update_user_role_v4
from .wrappers import admin_update_user_role_v4_async
from .wrappers import admin_update_user_v4
from .wrappers import admin_update_user_v4_async
from .wrappers import create_user_from_invitation_v4
from .wrappers import create_user_from_invitation_v4_async
from .wrappers import public_create_test_user_v4
from .wrappers import public_create_test_user_v4_async
from .wrappers import public_create_user_v4
from .wrappers import public_create_user_v4_async
from .wrappers import public_disable_my_authenticator_v4
from .wrappers import public_disable_my_authenticator_v4_async
from .wrappers import public_disable_my_backup_codes_v4
from .wrappers import public_disable_my_backup_codes_v4_async
from .wrappers import public_download_my_backup_codes_v4
from .wrappers import public_download_my_backup_codes_v4_async
from .wrappers import public_enable_my_authenticator_v4
from .wrappers import public_enable_my_authenticator_v4_async
from .wrappers import public_enable_my_backup_codes_v4
from .wrappers import public_enable_my_backup_codes_v4_async
from .wrappers import public_generate_my_authenticator_key_v4
from .wrappers import public_generate_my_authenticator_key_v4_async
from .wrappers import public_generate_my_backup_codes_v4
from .wrappers import public_generate_my_backup_codes_v4_async
from .wrappers import public_get_my_backup_codes_v4
from .wrappers import public_get_my_backup_codes_v4_async
from .wrappers import public_get_my_enabled_factors_v4
from .wrappers import public_get_my_enabled_factors_v4_async
from .wrappers import public_make_factor_my_default_v4
from .wrappers import public_make_factor_my_default_v4_async
from .wrappers import public_remove_trusted_device_v4
from .wrappers import public_remove_trusted_device_v4_async
from .wrappers import public_update_user_email_address_v4
from .wrappers import public_update_user_email_address_v4_async
from .wrappers import public_update_user_v4
from .wrappers import public_update_user_v4_async
from .wrappers import public_upgrade_headless_account_v4
from .wrappers import public_upgrade_headless_account_v4_async
from .wrappers import public_upgrade_headless_account_with_verification_code_v4
from .wrappers import public_upgrade_headless_account_with_verification_code_v4_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Social Service."""

__version__ = "1.29.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_create_user_stat_items import BulkCreateUserStatItems
from .bulk_fetch_or_default_s_50dfdc import BulkFetchOrDefaultStatItems
from .bulk_fetch_or_default_s_d6fcc5 import BulkFetchOrDefaultStatItems1
from .bulk_fetch_stat_items import BulkFetchStatItems
from .bulk_fetch_stat_items_1 import BulkFetchStatItems1
from .bulk_inc_user_stat_item import BulkIncUserStatItem
from .bulk_inc_user_stat_item_1 import BulkIncUserStatItem1
from .bulk_inc_user_stat_item_value import BulkIncUserStatItemValue
from .bulk_inc_user_stat_item_b0004a import BulkIncUserStatItemValue1
from .bulk_inc_user_stat_item_0f5ee3 import BulkIncUserStatItemValue2
from .bulk_reset_user_stat_item import BulkResetUserStatItem
from .bulk_reset_user_stat_item_1 import BulkResetUserStatItem1
from .bulk_reset_user_stat_item_2 import BulkResetUserStatItem2
from .bulk_reset_user_stat_item_3 import BulkResetUserStatItem3
from .bulk_reset_user_stat_it_ed9334 import BulkResetUserStatItemValues
from .bulk_update_user_stat_item import BulkUpdateUserStatItem
from .bulk_update_user_stat_item_1 import BulkUpdateUserStatItem1
from .bulk_update_user_stat_item_2 import BulkUpdateUserStatItem2
from .bulk_update_user_stat_item_v2 import BulkUpdateUserStatItemV2
from .create_user_stat_item import CreateUserStatItem
from .delete_user_stat_items import DeleteUserStatItems
from .delete_user_stat_items_1 import DeleteUserStatItems1
from .delete_user_stat_items_2 import DeleteUserStatItems2
from .get_user_stat_items import GetUserStatItems
from .inc_user_stat_item_value import IncUserStatItemValue
from .public_bulk_create_user_ce1688 import PublicBulkCreateUserStatItems
from .public_bulk_inc_user_stat_item import PublicBulkIncUserStatItem
from .public_bulk_inc_user_st_308993 import PublicBulkIncUserStatItem1
from .public_bulk_inc_user_st_374b4e import PublicBulkIncUserStatItemValue
from .public_create_user_stat_item import PublicCreateUserStatItem
from .public_inc_user_stat_item import PublicIncUserStatItem
from .public_inc_user_stat_it_1d89c5 import PublicIncUserStatItemValue
from .public_query_user_stat_items import PublicQueryUserStatItems
from .public_query_user_stat_items_1 import PublicQueryUserStatItems1
from .public_query_user_stat_items_2 import PublicQueryUserStatItems2
from .reset_user_stat_item_value import ResetUserStatItemValue
from .reset_user_stat_item_value_1 import ResetUserStatItemValue1
from .update_user_stat_item_value import UpdateUserStatItemValue
from .update_user_stat_item_value_1 import UpdateUserStatItemValue1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.16.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.accountcommon_pagination_v3 import AccountcommonPaginationV3
from ..models.clientmodel_client_v3_response import ClientmodelClientV3Response


class ClientmodelClientsV3Response(Model):
    """Clientmodel clients V3 response (clientmodel.ClientsV3Response)

    Properties:
        data: (data) REQUIRED List[ClientmodelClientV3Response]

        paging: (paging) REQUIRED AccountcommonPaginationV3
    """

    # region fields

    data: List[ClientmodelClientV3Response]  # REQUIRED
    paging: AccountcommonPaginationV3  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_data(
        self, value: List[ClientmodelClientV3Response]
    ) -> ClientmodelClientsV3Response:
        self.data = value
        return self

    def with_paging(
        self, value: AccountcommonPaginationV3
    ) -> ClientmodelClientsV3Response:
        self.paging = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "data"):
            result["data"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.data
            ]
        elif include_empty:
            result["data"] = []
        if hasattr(self, "paging"):
            result["paging"] = self.paging.to_dict(include_empty=include_empty)
        elif include_empty:
            result["paging"] = AccountcommonPaginationV3()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        data: List[ClientmodelClientV3Response],
        paging: AccountcommonPaginationV3,
    ) -> ClientmodelClientsV3Response:
        instance = cls()
        instance.data = data
        instance.paging = paging
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ClientmodelClientsV3Response:
        instance = cls()
        if not dict_:
            return instance
        if "data" in dict_ and dict_["data"] is not None:
            instance.data = [
                ClientmodelClientV3Response.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["data"]
            ]
        elif include_empty:
            instance.data = []
        if "paging" in dict_ and dict_["paging"] is not None:
            instance.paging = AccountcommonPaginationV3.create_from_dict(
                dict_["paging"], include_empty=include_empty
            )
        elif include_empty:
            instance.paging = AccountcommonPaginationV3()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ClientmodelClientsV3Response]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ClientmodelClientsV3Response]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ClientmodelClientsV3Response,
        List[ClientmodelClientsV3Response],
        Dict[Any, ClientmodelClientsV3Response],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "data": "data",
            "paging": "paging",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "data": True,
            "paging": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.16.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelUserPermissionsResponseV3(Model):
    """Model user permissions response V3 (model.UserPermissionsResponseV3)

    Properties:
        action: (action) REQUIRED int

        resource: (resource) REQUIRED str

        sched_action: (schedAction) OPTIONAL int

        sched_cron: (schedCron) OPTIONAL str

        sched_range: (schedRange) OPTIONAL List[str]
    """

    # region fields

    action: int  # REQUIRED
    resource: str  # REQUIRED
    sched_action: int  # OPTIONAL
    sched_cron: str  # OPTIONAL
    sched_range: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_action(self, value: int) -> ModelUserPermissionsResponseV3:
        self.action = value
        return self

    def with_resource(self, value: str) -> ModelUserPermissionsResponseV3:
        self.resource = value
        return self

    def with_sched_action(self, value: int) -> ModelUserPermissionsResponseV3:
        self.sched_action = value
        return self

    def with_sched_cron(self, value: str) -> ModelUserPermissionsResponseV3:
        self.sched_cron = value
        return self

    def with_sched_range(self, value: List[str]) -> ModelUserPermissionsResponseV3:
        self.sched_range = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "action"):
            result["action"] = int(self.action)
        elif include_empty:
            result["action"] = 0
        if hasattr(self, "resource"):
            result["resource"] = str(self.resource)
        elif include_empty:
            result["resource"] = ""
        if hasattr(self, "sched_action"):
            result["schedAction"] = int(self.sched_action)
        elif include_empty:
            result["schedAction"] = 0
        if hasattr(self, "sched_cron"):
            result["schedCron"] = str(self.sched_cron)
        elif include_empty:
            result["schedCron"] = ""
        if hasattr(self, "sched_range"):
            result["schedRange"] = [str(i0) for i0 in self.sched_range]
        elif include_empty:
            result["schedRange"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        action: int,
        resource: str,
        sched_action: Optional[int] = None,
        sched_cron: Optional[str] = None,
        sched_range: Optional[List[str]] = None,
    ) -> ModelUserPermissionsResponseV3:
        instance = cls()
        instance.action = action
        instance.resource = resource
        if sched_action is not None:
            instance.sched_action = sched_action
        if sched_cron is not None:
            instance.sched_cron = sched_cron
        if sched_range is not None:
            instance.sched_range = sched_range
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelUserPermissionsResponseV3:
        instance = cls()
        if not dict_:
            return instance
        if "action" in dict_ and dict_["action"] is not None:
            instance.action = int(dict_["action"])
        elif include_empty:
            instance.action = 0
        if "resource" in dict_ and dict_["resource"] is not None:
            instance.resource = str(dict_["resource"])
        elif include_empty:
            instance.resource = ""
        if "schedAction" in dict_ and dict_["schedAction"] is not None:
            instance.sched_action = int(dict_["schedAction"])
        elif include_empty:
            instance.sched_action = 0
        if "schedCron" in dict_ and dict_["schedCron"] is not None:
            instance.sched_cron = str(dict_["schedCron"])
        elif include_empty:
            instance.sched_cron = ""
        if "schedRange" in dict_ and dict_["schedRange"] is not None:
            instance.sched_range = [str(i0) for i0 in dict_["schedRange"]]
        elif include_empty:
            instance.sched_range = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelUserPermissionsResponseV3]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelUserPermissionsResponseV3]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelUserPermissionsResponseV3,
        List[ModelUserPermissionsResponseV3],
        Dict[Any, ModelUserPermissionsResponseV3],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "action": "action",
            "resource": "resource",
            "schedAction": "sched_action",
            "schedCron": "sched_cron",
            "schedRange": "sched_range",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "action": True,
            "resource": True,
            "schedAction": False,
            "schedCron": False,
            "schedRange": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.14.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum

from ..models.image import Image
from ..models.localization import Localization
from ..models.option_box_config import OptionBoxConfig
from ..models.purchase_condition import PurchaseCondition
from ..models.recurring import Recurring
from ..models.region_data_item import RegionDataItem


class EntitlementTypeEnum(StrEnum):
    CONSUMABLE = "CONSUMABLE"
    DURABLE = "DURABLE"


class ItemTypeEnum(StrEnum):
    APP = "APP"
    BUNDLE = "BUNDLE"
    CODE = "CODE"
    COINS = "COINS"
    EXTENSION = "EXTENSION"
    INGAMEITEM = "INGAMEITEM"
    MEDIA = "MEDIA"
    OPTIONBOX = "OPTIONBOX"
    SEASON = "SEASON"
    SUBSCRIPTION = "SUBSCRIPTION"


class StatusEnum(StrEnum):
    ACTIVE = "ACTIVE"
    INACTIVE = "INACTIVE"


class AppTypeEnum(StrEnum):
    DEMO = "DEMO"
    DLC = "DLC"
    GAME = "GAME"
    SOFTWARE = "SOFTWARE"


class SeasonTypeEnum(StrEnum):
    PASS = "PASS"
    TIER = "TIER"


class FullItemInfo(Model):
    """Full item info (FullItemInfo)

    Properties:
        category_path: (categoryPath) REQUIRED str

        created_at: (createdAt) REQUIRED str

        entitlement_type: (entitlementType) REQUIRED Union[str, EntitlementTypeEnum]

        item_id: (itemId) REQUIRED str

        item_type: (itemType) REQUIRED Union[str, ItemTypeEnum]

        localizations: (localizations) REQUIRED Dict[str, Localization]

        name: (name) REQUIRED str

        namespace: (namespace) REQUIRED str

        region_data: (regionData) REQUIRED Dict[str, List[RegionDataItem]]

        status: (status) REQUIRED Union[str, StatusEnum]

        updated_at: (updatedAt) REQUIRED str

        app_id: (appId) OPTIONAL str

        app_type: (appType) OPTIONAL Union[str, AppTypeEnum]

        base_app_id: (baseAppId) OPTIONAL str

        booth_name: (boothName) OPTIONAL str

        bound_item_ids: (boundItemIds) OPTIONAL List[str]

        clazz: (clazz) OPTIONAL str

        display_order: (displayOrder) OPTIONAL int

        ext: (ext) OPTIONAL Dict[str, Any]

        features: (features) OPTIONAL List[str]

        images: (images) OPTIONAL List[Image]

        item_ids: (itemIds) OPTIONAL List[str]

        item_qty: (itemQty) OPTIONAL Dict[str, int]

        listable: (listable) OPTIONAL bool

        max_count: (maxCount) OPTIONAL int

        max_count_per_user: (maxCountPerUser) OPTIONAL int

        option_box_config: (optionBoxConfig) OPTIONAL OptionBoxConfig

        purchasable: (purchasable) OPTIONAL bool

        purchase_condition: (purchaseCondition) OPTIONAL PurchaseCondition

        recurring: (recurring) OPTIONAL Recurring

        season_type: (seasonType) OPTIONAL Union[str, SeasonTypeEnum]

        sku: (sku) OPTIONAL str

        stackable: (stackable) OPTIONAL bool

        tags: (tags) OPTIONAL List[str]

        target_currency_code: (targetCurrencyCode) OPTIONAL str

        target_item_id: (targetItemId) OPTIONAL str

        target_namespace: (targetNamespace) OPTIONAL str

        thumbnail_url: (thumbnailUrl) OPTIONAL str

        use_count: (useCount) OPTIONAL int
    """

    # region fields

    category_path: str  # REQUIRED
    created_at: str  # REQUIRED
    entitlement_type: Union[str, EntitlementTypeEnum]  # REQUIRED
    item_id: str  # REQUIRED
    item_type: Union[str, ItemTypeEnum]  # REQUIRED
    localizations: Dict[str, Localization]  # REQUIRED
    name: str  # REQUIRED
    namespace: str  # REQUIRED
    region_data: Dict[str, List[RegionDataItem]]  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    updated_at: str  # REQUIRED
    app_id: str  # OPTIONAL
    app_type: Union[str, AppTypeEnum]  # OPTIONAL
    base_app_id: str  # OPTIONAL
    booth_name: str  # OPTIONAL
    bound_item_ids: List[str]  # OPTIONAL
    clazz: str  # OPTIONAL
    display_order: int  # OPTIONAL
    ext: Dict[str, Any]  # OPTIONAL
    features: List[str]  # OPTIONAL
    images: List[Image]  # OPTIONAL
    item_ids: List[str]  # OPTIONAL
    item_qty: Dict[str, int]  # OPTIONAL
    listable: bool  # OPTIONAL
    max_count: int  # OPTIONAL
    max_count_per_user: int  # OPTIONAL
    option_box_config: OptionBoxConfig  # OPTIONAL
    purchasable: bool  # OPTIONAL
    purchase_condition: PurchaseCondition  # OPTIONAL
    recurring: Recurring  # OPTIONAL
    season_type: Union[str, SeasonTypeEnum]  # OPTIONAL
    sku: str  # OPTIONAL
    stackable: bool  # OPTIONAL
    tags: List[str]  # OPTIONAL
    target_currency_code: str  # OPTIONAL
    target_item_id: str  # OPTIONAL
    target_namespace: str  # OPTIONAL
    thumbnail_url: str  # OPTIONAL
    use_count: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_category_path(self, value: str) -> FullItemInfo:
        self.category_path = value
        return self

    def with_created_at(self, value: str) -> FullItemInfo:
        self.created_at = value
        return self

    def with_entitlement_type(
        self, value: Union[str, EntitlementTypeEnum]
    ) -> FullItemInfo:
        self.entitlement_type = value
        return self

    def with_item_id(self, value: str) -> FullItemInfo:
        self.item_id = value
        return self

    def with_item_type(self, value: Union[str, ItemTypeEnum]) -> FullItemInfo:
        self.item_type = value
        return self

    def with_localizations(self, value: Dict[str, Localization]) -> FullItemInfo:
        self.localizations = value
        return self

    def with_name(self, value: str) -> FullItemInfo:
        self.name = value
        return self

    def with_namespace(self, value: str) -> FullItemInfo:
        self.namespace = value
        return self

    def with_region_data(self, value: Dict[str, List[RegionDataItem]]) -> FullItemInfo:
        self.region_data = value
        return self

    def with_status(self, value: Union[str, StatusEnum]) -> FullItemInfo:
        self.status = value
        return self

    def with_updated_at(self, value: str) -> FullItemInfo:
        self.updated_at = value
        return self

    def with_app_id(self, value: str) -> FullItemInfo:
        self.app_id = value
        return self

    def with_app_type(self, value: Union[str, AppTypeEnum]) -> FullItemInfo:
        self.app_type = value
        return self

    def with_base_app_id(self, value: str) -> FullItemInfo:
        self.base_app_id = value
        return self

    def with_booth_name(self, value: str) -> FullItemInfo:
        self.booth_name = value
        return self

    def with_bound_item_ids(self, value: List[str]) -> FullItemInfo:
        self.bound_item_ids = value
        return self

    def with_clazz(self, value: str) -> FullItemInfo:
        self.clazz = value
        return self

    def with_display_order(self, value: int) -> FullItemInfo:
        self.display_order = value
        return self

    def with_ext(self, value: Dict[str, Any]) -> FullItemInfo:
        self.ext = value
        return self

    def with_features(self, value: List[str]) -> FullItemInfo:
        self.features = value
        return self

    def with_images(self, value: List[Image]) -> FullItemInfo:
        self.images = value
        return self

    def with_item_ids(self, value: List[str]) -> FullItemInfo:
        self.item_ids = value
        return self

    def with_item_qty(self, value: Dict[str, int]) -> FullItemInfo:
        self.item_qty = value
        return self

    def with_listable(self, value: bool) -> FullItemInfo:
        self.listable = value
        return self

    def with_max_count(self, value: int) -> FullItemInfo:
        self.max_count = value
        return self

    def with_max_count_per_user(self, value: int) -> FullItemInfo:
        self.max_count_per_user = value
        return self

    def with_option_box_config(self, value: OptionBoxConfig) -> FullItemInfo:
        self.option_box_config = value
        return self

    def with_purchasable(self, value: bool) -> FullItemInfo:
        self.purchasable = value
        return self

    def with_purchase_condition(self, value: PurchaseCondition) -> FullItemInfo:
        self.purchase_condition = value
        return self

    def with_recurring(self, value: Recurring) -> FullItemInfo:
        self.recurring = value
        return self

    def with_season_type(self, value: Union[str, SeasonTypeEnum]) -> FullItemInfo:
        self.season_type = value
        return self

    def with_sku(self, value: str) -> FullItemInfo:
        self.sku = value
        return self

    def with_stackable(self, value: bool) -> FullItemInfo:
        self.stackable = value
        return self

    def with_tags(self, value: List[str]) -> FullItemInfo:
        self.tags = value
        return self

    def with_target_currency_code(self, value: str) -> FullItemInfo:
        self.target_currency_code = value
        return self

    def with_target_item_id(self, value: str) -> FullItemInfo:
        self.target_item_id = value
        return self

    def with_target_namespace(self, value: str) -> FullItemInfo:
        self.target_namespace = value
        return self

    def with_thumbnail_url(self, value: str) -> FullItemInfo:
        self.thumbnail_url = value
        return self

    def with_use_count(self, value: int) -> FullItemInfo:
        self.use_count = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "category_path"):
            result["categoryPath"] = str(self.category_path)
        elif include_empty:
            result["categoryPath"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "entitlement_type"):
            result["entitlementType"] = str(self.entitlement_type)
        elif include_empty:
            result["entitlementType"] = Union[str, EntitlementTypeEnum]()
        if hasattr(self, "item_id"):
            result["itemId"] = str(self.item_id)
        elif include_empty:
            result["itemId"] = ""
        if hasattr(self, "item_type"):
            result["itemType"] = str(self.item_type)
        elif include_empty:
            result["itemType"] = Union[str, ItemTypeEnum]()
        if hasattr(self, "localizations"):
            result["localizations"] = {
                str(k0): v0.to_dict(include_empty=include_empty)
                for k0, v0 in self.localizations.items()
            }
        elif include_empty:
            result["localizations"] = {}
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "region_data"):
            result["regionData"] = {
                str(k0): [i1.to_dict(include_empty=include_empty) for i1 in v0]
                for k0, v0 in self.region_data.items()
            }
        elif include_empty:
            result["regionData"] = {}
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "app_id"):
            result["appId"] = str(self.app_id)
        elif include_empty:
            result["appId"] = ""
        if hasattr(self, "app_type"):
            result["appType"] = str(self.app_type)
        elif include_empty:
            result["appType"] = Union[str, AppTypeEnum]()
        if hasattr(self, "base_app_id"):
            result["baseAppId"] = str(self.base_app_id)
        elif include_empty:
            result["baseAppId"] = ""
        if hasattr(self, "booth_name"):
            result["boothName"] = str(self.booth_name)
        elif include_empty:
            result["boothName"] = ""
        if hasattr(self, "bound_item_ids"):
            result["boundItemIds"] = [str(i0) for i0 in self.bound_item_ids]
        elif include_empty:
            result["boundItemIds"] = []
        if hasattr(self, "clazz"):
            result["clazz"] = str(self.clazz)
        elif include_empty:
            result["clazz"] = ""
        if hasattr(self, "display_order"):
            result["displayOrder"] = int(self.display_order)
        elif include_empty:
            result["displayOrder"] = 0
        if hasattr(self, "ext"):
            result["ext"] = {str(k0): v0 for k0, v0 in self.ext.items()}
        elif include_empty:
            result["ext"] = {}
        if hasattr(self, "features"):
            result["features"] = [str(i0) for i0 in self.features]
        elif include_empty:
            result["features"] = []
        if hasattr(self, "images"):
            result["images"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.images
            ]
        elif include_empty:
            result["images"] = []
        if hasattr(self, "item_ids"):
            result["itemIds"] = [str(i0) for i0 in self.item_ids]
        elif include_empty:
            result["itemIds"] = []
        if hasattr(self, "item_qty"):
            result["itemQty"] = {str(k0): int(v0) for k0, v0 in self.item_qty.items()}
        elif include_empty:
            result["itemQty"] = {}
        if hasattr(self, "listable"):
            result["listable"] = bool(self.listable)
        elif include_empty:
            result["listable"] = False
        if hasattr(self, "max_count"):
            result["maxCount"] = int(self.max_count)
        elif include_empty:
            result["maxCount"] = 0
        if hasattr(self, "max_count_per_user"):
            result["maxCountPerUser"] = int(self.max_count_per_user)
        elif include_empty:
            result["maxCountPerUser"] = 0
        if hasattr(self, "option_box_config"):
            result["optionBoxConfig"] = self.option_box_config.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["optionBoxConfig"] = OptionBoxConfig()
        if hasattr(self, "purchasable"):
            result["purchasable"] = bool(self.purchasable)
        elif include_empty:
            result["purchasable"] = False
        if hasattr(self, "purchase_condition"):
            result["purchaseCondition"] = self.purchase_condition.to_dict(
                include_empty=include_empty
            )
        elif include_empty:
            result["purchaseCondition"] = PurchaseCondition()
        if hasattr(self, "recurring"):
            result["recurring"] = self.recurring.to_dict(include_empty=include_empty)
        elif include_empty:
            result["recurring"] = Recurring()
        if hasattr(self, "season_type"):
            result["seasonType"] = str(self.season_type)
        elif include_empty:
            result["seasonType"] = Union[str, SeasonTypeEnum]()
        if hasattr(self, "sku"):
            result["sku"] = str(self.sku)
        elif include_empty:
            result["sku"] = ""
        if hasattr(self, "stackable"):
            result["stackable"] = bool(self.stackable)
        elif include_empty:
            result["stackable"] = False
        if hasattr(self, "tags"):
            result["tags"] = [str(i0) for i0 in self.tags]
        elif include_empty:
            result["tags"] = []
        if hasattr(self, "target_currency_code"):
            result["targetCurrencyCode"] = str(self.target_currency_code)
        elif include_empty:
            result["targetCurrencyCode"] = ""
        if hasattr(self, "target_item_id"):
            result["targetItemId"] = str(self.target_item_id)
        elif include_empty:
            result["targetItemId"] = ""
        if hasattr(self, "target_namespace"):
            result["targetNamespace"] = str(self.target_namespace)
        elif include_empty:
            result["targetNamespace"] = ""
        if hasattr(self, "thumbnail_url"):
            result["thumbnailUrl"] = str(self.thumbnail_url)
        elif include_empty:
            result["thumbnailUrl"] = ""
        if hasattr(self, "use_count"):
            result["useCount"] = int(self.use_count)
        elif include_empty:
            result["useCount"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        category_path: str,
        created_at: str,
        entitlement_type: Union[str, EntitlementTypeEnum],
        item_id: str,
        item_type: Union[str, ItemTypeEnum],
        localizations: Dict[str, Localization],
        name: str,
        namespace: str,
        region_data: Dict[str, List[RegionDataItem]],
        status: Union[str, StatusEnum],
        updated_at: str,
        app_id: Optional[str] = None,
        app_type: Optional[Union[str, AppTypeEnum]] = None,
        base_app_id: Optional[str] = None,
        booth_name: Optional[str] = None,
        bound_item_ids: Optional[List[str]] = None,
        clazz: Optional[str] = None,
        display_order: Optional[int] = None,
        ext: Optional[Dict[str, Any]] = None,
        features: Optional[List[str]] = None,
        images: Optional[List[Image]] = None,
        item_ids: Optional[List[str]] = None,
        item_qty: Optional[Dict[str, int]] = None,
        listable: Optional[bool] = None,
        max_count: Optional[int] = None,
        max_count_per_user: Optional[int] = None,
        option_box_config: Optional[OptionBoxConfig] = None,
        purchasable: Optional[bool] = None,
        purchase_condition: Optional[PurchaseCondition] = None,
        recurring: Optional[Recurring] = None,
        season_type: Optional[Union[str, SeasonTypeEnum]] = None,
        sku: Optional[str] = None,
        stackable: Optional[bool] = None,
        tags: Optional[List[str]] = None,
        target_currency_code: Optional[str] = None,
        target_item_id: Optional[str] = None,
        target_namespace: Optional[str] = None,
        thumbnail_url: Optional[str] = None,
        use_count: Optional[int] = None,
    ) -> FullItemInfo:
        instance = cls()
        instance.category_path = category_path
        instance.created_at = created_at
        instance.entitlement_type = entitlement_type
        instance.item_id = item_id
        instance.item_type = item_type
        instance.localizations = localizations
        instance.name = name
        instance.namespace = namespace
        instance.region_data = region_data
        instance.status = status
        instance.updated_at = updated_at
        if app_id is not None:
            instance.app_id = app_id
        if app_type is not None:
            instance.app_type = app_type
        if base_app_id is not None:
            instance.base_app_id = base_app_id
        if booth_name is not None:
            instance.booth_name = booth_name
        if bound_item_ids is not None:
            instance.bound_item_ids = bound_item_ids
        if clazz is not None:
            instance.clazz = clazz
        if display_order is not None:
            instance.display_order = display_order
        if ext is not None:
            instance.ext = ext
        if features is not None:
            instance.features = features
        if images is not None:
            instance.images = images
        if item_ids is not None:
            instance.item_ids = item_ids
        if item_qty is not None:
            instance.item_qty = item_qty
        if listable is not None:
            instance.listable = listable
        if max_count is not None:
            instance.max_count = max_count
        if max_count_per_user is not None:
            instance.max_count_per_user = max_count_per_user
        if option_box_config is not None:
            instance.option_box_config = option_box_config
        if purchasable is not None:
            instance.purchasable = purchasable
        if purchase_condition is not None:
            instance.purchase_condition = purchase_condition
        if recurring is not None:
            instance.recurring = recurring
        if season_type is not None:
            instance.season_type = season_type
        if sku is not None:
            instance.sku = sku
        if stackable is not None:
            instance.stackable = stackable
        if tags is not None:
            instance.tags = tags
        if target_currency_code is not None:
            instance.target_currency_code = target_currency_code
        if target_item_id is not None:
            instance.target_item_id = target_item_id
        if target_namespace is not None:
            instance.target_namespace = target_namespace
        if thumbnail_url is not None:
            instance.thumbnail_url = thumbnail_url
        if use_count is not None:
            instance.use_count = use_count
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> FullItemInfo:
        instance = cls()
        if not dict_:
            return instance
        if "categoryPath" in dict_ and dict_["categoryPath"] is not None:
            instance.category_path = str(dict_["categoryPath"])
        elif include_empty:
            instance.category_path = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "entitlementType" in dict_ and dict_["entitlementType"] is not None:
            instance.entitlement_type = str(dict_["entitlementType"])
        elif include_empty:
            instance.entitlement_type = Union[str, EntitlementTypeEnum]()
        if "itemId" in dict_ and dict_["itemId"] is not None:
            instance.item_id = str(dict_["itemId"])
        elif include_empty:
            instance.item_id = ""
        if "itemType" in dict_ and dict_["itemType"] is not None:
            instance.item_type = str(dict_["itemType"])
        elif include_empty:
            instance.item_type = Union[str, ItemTypeEnum]()
        if "localizations" in dict_ and dict_["localizations"] is not None:
            instance.localizations = {
                str(k0): Localization.create_from_dict(v0, include_empty=include_empty)
                for k0, v0 in dict_["localizations"].items()
            }
        elif include_empty:
            instance.localizations = {}
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "regionData" in dict_ and dict_["regionData"] is not None:
            instance.region_data = {
                str(k0): [
                    RegionDataItem.create_from_dict(i1, include_empty=include_empty)
                    for i1 in v0
                ]
                for k0, v0 in dict_["regionData"].items()
            }
        elif include_empty:
            instance.region_data = {}
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "appId" in dict_ and dict_["appId"] is not None:
            instance.app_id = str(dict_["appId"])
        elif include_empty:
            instance.app_id = ""
        if "appType" in dict_ and dict_["appType"] is not None:
            instance.app_type = str(dict_["appType"])
        elif include_empty:
            instance.app_type = Union[str, AppTypeEnum]()
        if "baseAppId" in dict_ and dict_["baseAppId"] is not None:
            instance.base_app_id = str(dict_["baseAppId"])
        elif include_empty:
            instance.base_app_id = ""
        if "boothName" in dict_ and dict_["boothName"] is not None:
            instance.booth_name = str(dict_["boothName"])
        elif include_empty:
            instance.booth_name = ""
        if "boundItemIds" in dict_ and dict_["boundItemIds"] is not None:
            instance.bound_item_ids = [str(i0) for i0 in dict_["boundItemIds"]]
        elif include_empty:
            instance.bound_item_ids = []
        if "clazz" in dict_ and dict_["clazz"] is not None:
            instance.clazz = str(dict_["clazz"])
        elif include_empty:
            instance.clazz = ""
        if "displayOrder" in dict_ and dict_["displayOrder"] is not None:
            instance.display_order = int(dict_["displayOrder"])
        elif include_empty:
            instance.display_order = 0
        if "ext" in dict_ and dict_["ext"] is not None:
            instance.ext = {str(k0): v0 for k0, v0 in dict_["ext"].items()}
        elif include_empty:
            instance.ext = {}
        if "features" in dict_ and dict_["features"] is not None:
            instance.features = [str(i0) for i0 in dict_["features"]]
        elif include_empty:
            instance.features = []
        if "images" in dict_ and dict_["images"] is not None:
            instance.images = [
                Image.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["images"]
            ]
        elif include_empty:
            instance.images = []
        if "itemIds" in dict_ and dict_["itemIds"] is not None:
            instance.item_ids = [str(i0) for i0 in dict_["itemIds"]]
        elif include_empty:
            instance.item_ids = []
        if "itemQty" in dict_ and dict_["itemQty"] is not None:
            instance.item_qty = {
                str(k0): int(v0) for k0, v0 in dict_["itemQty"].items()
            }
        elif include_empty:
            instance.item_qty = {}
        if "listable" in dict_ and dict_["listable"] is not None:
            instance.listable = bool(dict_["listable"])
        elif include_empty:
            instance.listable = False
        if "maxCount" in dict_ and dict_["maxCount"] is not None:
            instance.max_count = int(dict_["maxCount"])
        elif include_empty:
            instance.max_count = 0
        if "maxCountPerUser" in dict_ and dict_["maxCountPerUser"] is not None:
            instance.max_count_per_user = int(dict_["maxCountPerUser"])
        elif include_empty:
            instance.max_count_per_user = 0
        if "optionBoxConfig" in dict_ and dict_["optionBoxConfig"] is not None:
            instance.option_box_config = OptionBoxConfig.create_from_dict(
                dict_["optionBoxConfig"], include_empty=include_empty
            )
        elif include_empty:
            instance.option_box_config = OptionBoxConfig()
        if "purchasable" in dict_ and dict_["purchasable"] is not None:
            instance.purchasable = bool(dict_["purchasable"])
        elif include_empty:
            instance.purchasable = False
        if "purchaseCondition" in dict_ and dict_["purchaseCondition"] is not None:
            instance.purchase_condition = PurchaseCondition.create_from_dict(
                dict_["purchaseCondition"], include_empty=include_empty
            )
        elif include_empty:
            instance.purchase_condition = PurchaseCondition()
        if "recurring" in dict_ and dict_["recurring"] is not None:
            instance.recurring = Recurring.create_from_dict(
                dict_["recurring"], include_empty=include_empty
            )
        elif include_empty:
            instance.recurring = Recurring()
        if "seasonType" in dict_ and dict_["seasonType"] is not None:
            instance.season_type = str(dict_["seasonType"])
        elif include_empty:
            instance.season_type = Union[str, SeasonTypeEnum]()
        if "sku" in dict_ and dict_["sku"] is not None:
            instance.sku = str(dict_["sku"])
        elif include_empty:
            instance.sku = ""
        if "stackable" in dict_ and dict_["stackable"] is not None:
            instance.stackable = bool(dict_["stackable"])
        elif include_empty:
            instance.stackable = False
        if "tags" in dict_ and dict_["tags"] is not None:
            instance.tags = [str(i0) for i0 in dict_["tags"]]
        elif include_empty:
            instance.tags = []
        if "targetCurrencyCode" in dict_ and dict_["targetCurrencyCode"] is not None:
            instance.target_currency_code = str(dict_["targetCurrencyCode"])
        elif include_empty:
            instance.target_currency_code = ""
        if "targetItemId" in dict_ and dict_["targetItemId"] is not None:
            instance.target_item_id = str(dict_["targetItemId"])
        elif include_empty:
            instance.target_item_id = ""
        if "targetNamespace" in dict_ and dict_["targetNamespace"] is not None:
            instance.target_namespace = str(dict_["targetNamespace"])
        elif include_empty:
            instance.target_namespace = ""
        if "thumbnailUrl" in dict_ and dict_["thumbnailUrl"] is not None:
            instance.thumbnail_url = str(dict_["thumbnailUrl"])
        elif include_empty:
            instance.thumbnail_url = ""
        if "useCount" in dict_ and dict_["useCount"] is not None:
            instance.use_count = int(dict_["useCount"])
        elif include_empty:
            instance.use_count = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, FullItemInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[FullItemInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[FullItemInfo, List[FullItemInfo], Dict[Any, FullItemInfo]]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "categoryPath": "category_path",
            "createdAt": "created_at",
            "entitlementType": "entitlement_type",
            "itemId": "item_id",
            "itemType": "item_type",
            "localizations": "localizations",
            "name": "name",
            "namespace": "namespace",
            "regionData": "region_data",
            "status": "status",
            "updatedAt": "updated_at",
            "appId": "app_id",
            "appType": "app_type",
            "baseAppId": "base_app_id",
            "boothName": "booth_name",
            "boundItemIds": "bound_item_ids",
            "clazz": "clazz",
            "displayOrder": "display_order",
            "ext": "ext",
            "features": "features",
            "images": "images",
            "itemIds": "item_ids",
            "itemQty": "item_qty",
            "listable": "listable",
            "maxCount": "max_count",
            "maxCountPerUser": "max_count_per_user",
            "optionBoxConfig": "option_box_config",
            "purchasable": "purchasable",
            "purchaseCondition": "purchase_condition",
            "recurring": "recurring",
            "seasonType": "season_type",
            "sku": "sku",
            "stackable": "stackable",
            "tags": "tags",
            "targetCurrencyCode": "target_currency_code",
            "targetItemId": "target_item_id",
            "targetNamespace": "target_namespace",
            "thumbnailUrl": "thumbnail_url",
            "useCount": "use_count",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "categoryPath": True,
            "createdAt": True,
            "entitlementType": True,
            "itemId": True,
            "itemType": True,
            "localizations": True,
            "name": True,
            "namespace": True,
            "regionData": True,
            "status": True,
            "updatedAt": True,
            "appId": False,
            "appType": False,
            "baseAppId": False,
            "boothName": False,
            "boundItemIds": False,
            "clazz": False,
            "displayOrder": False,
            "ext": False,
            "features": False,
            "images": False,
            "itemIds": False,
            "itemQty": False,
            "listable": False,
            "maxCount": False,
            "maxCountPerUser": False,
            "optionBoxConfig": False,
            "purchasable": False,
            "purchaseCondition": False,
            "recurring": False,
            "seasonType": False,
            "sku": False,
            "stackable": False,
            "tags": False,
            "targetCurrencyCode": False,
            "targetItemId": False,
            "targetNamespace": False,
            "thumbnailUrl": False,
            "useCount": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "entitlementType": ["CONSUMABLE", "DURABLE"],
            "itemType": [
                "APP",
                "BUNDLE",
                "CODE",
                "COINS",
                "EXTENSION",
                "INGAMEITEM",
                "MEDIA",
                "OPTIONBOX",
                "SEASON",
                "SUBSCRIPTION",
            ],
            "status": ["ACTIVE", "INACTIVE"],
            "appType": ["DEMO", "DLC", "GAME", "SOFTWARE"],
            "seasonType": ["PASS", "TIER"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

"""Auto-generated package that contains models used by the AccelByte Cloud Basic Service."""

__version__ = "2.1.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .ban_users import BanUsers
from .get_actions import GetActions
from .get_banned_users import GetBannedUsers
from .get_user_status import GetUserStatus
from .public_report_user import PublicReportUser
from .report_user import ReportUser
from .un_ban_users import UnBanUsers



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Platform Service (4.14.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class AllowedBalanceOriginsEnum(StrEnum):
    EPIC = "Epic"
    GOOGLEPLAY = "GooglePlay"
    IOS = "IOS"
    NINTENDO = "Nintendo"
    OTHER = "Other"
    PLAYSTATION = "Playstation"
    STADIA = "Stadia"
    STEAM = "Steam"
    SYSTEM = "System"
    TWITCH = "Twitch"
    XBOX = "Xbox"


class PlatformWalletConfigUpdate(Model):
    """A DTO object for updating item API call. (PlatformWalletConfigUpdate)

    Properties:
        allowed_balance_origins: (allowedBalanceOrigins) OPTIONAL List[Union[str, AllowedBalanceOriginsEnum]]
    """

    # region fields

    allowed_balance_origins: List[Union[str, AllowedBalanceOriginsEnum]]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_allowed_balance_origins(
        self, value: List[Union[str, AllowedBalanceOriginsEnum]]
    ) -> PlatformWalletConfigUpdate:
        self.allowed_balance_origins = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "allowed_balance_origins"):
            result["allowedBalanceOrigins"] = [
                str(i0) for i0 in self.allowed_balance_origins
            ]
        elif include_empty:
            result["allowedBalanceOrigins"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        allowed_balance_origins: Optional[
            List[Union[str, AllowedBalanceOriginsEnum]]
        ] = None,
    ) -> PlatformWalletConfigUpdate:
        instance = cls()
        if allowed_balance_origins is not None:
            instance.allowed_balance_origins = allowed_balance_origins
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> PlatformWalletConfigUpdate:
        instance = cls()
        if not dict_:
            return instance
        if (
            "allowedBalanceOrigins" in dict_
            and dict_["allowedBalanceOrigins"] is not None
        ):
            instance.allowed_balance_origins = [
                str(i0) for i0 in dict_["allowedBalanceOrigins"]
            ]
        elif include_empty:
            instance.allowed_balance_origins = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, PlatformWalletConfigUpdate]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[PlatformWalletConfigUpdate]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        PlatformWalletConfigUpdate,
        List[PlatformWalletConfigUpdate],
        Dict[Any, PlatformWalletConfigUpdate],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "allowedBalanceOrigins": "allowed_balance_origins",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "allowedBalanceOrigins": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "allowedBalanceOrigins": [
                "Epic",
                "GooglePlay",
                "IOS",
                "Nintendo",
                "Other",
                "Playstation",
                "Stadia",
                "Steam",
                "System",
                "Twitch",
                "Xbox",
            ],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import FulfillmentScriptCreate
from ..models import FulfillmentScriptEvalTestRequest
from ..models import FulfillmentScriptEvalTestResult
from ..models import FulfillmentScriptInfo
from ..models import FulfillmentScriptUpdate

from ..operations.fulfillment_script import CreateFulfillmentScript
from ..operations.fulfillment_script import DeleteFulfillmentScript
from ..operations.fulfillment_script import GetFulfillmentScript
from ..operations.fulfillment_script import ListFulfillmentScripts
from ..operations.fulfillment_script import TestFulfillmentScriptEval
from ..operations.fulfillment_script import UpdateFulfillmentScript
from ..models import FulfillmentScriptEvalTestRequestTypeEnum


@same_doc_as(CreateFulfillmentScript)
def create_fulfillment_script(
    id_: str,
    body: Optional[FulfillmentScriptCreate] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreateFulfillmentScript.create(
        id_=id_,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateFulfillmentScript)
async def create_fulfillment_script_async(
    id_: str,
    body: Optional[FulfillmentScriptCreate] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreateFulfillmentScript.create(
        id_=id_,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteFulfillmentScript)
def delete_fulfillment_script(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = DeleteFulfillmentScript.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteFulfillmentScript)
async def delete_fulfillment_script_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = DeleteFulfillmentScript.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetFulfillmentScript)
def get_fulfillment_script(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetFulfillmentScript.create(
        id_=id_,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetFulfillmentScript)
async def get_fulfillment_script_async(
    id_: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = GetFulfillmentScript.create(
        id_=id_,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(ListFulfillmentScripts)
def list_fulfillment_scripts(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = ListFulfillmentScripts.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(ListFulfillmentScripts)
async def list_fulfillment_scripts_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    request = ListFulfillmentScripts.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(TestFulfillmentScriptEval)
def test_fulfillment_script_eval(
    body: Optional[FulfillmentScriptEvalTestRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestFulfillmentScriptEval.create(
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(TestFulfillmentScriptEval)
async def test_fulfillment_script_eval_async(
    body: Optional[FulfillmentScriptEvalTestRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = TestFulfillmentScriptEval.create(
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateFulfillmentScript)
def update_fulfillment_script(
    id_: str,
    body: Optional[FulfillmentScriptUpdate] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateFulfillmentScript.create(
        id_=id_,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateFulfillmentScript)
async def update_fulfillment_script_async(
    id_: str,
    body: Optional[FulfillmentScriptUpdate] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateFulfillmentScript.create(
        id_=id_,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import CreateLocalizedPolicyVersionRequest
from ..models import CreateLocalizedPolicyVersionResponse
from ..models import ErrorEntity
from ..models import RetrieveLocalizedPolicyVersionPublicResponse
from ..models import RetrieveLocalizedPolicyVersionResponse
from ..models import UpdateLocalizedPolicyVersionRequest
from ..models import UpdateLocalizedPolicyVersionResponse
from ..models import UploadLocalizedPolicyVersionAttachmentResponse
from ..models import UploadPolicyVersionAttachmentRequest

from ..operations.localized_policy_versions import CreateLocalizedPolicyVersion
from ..operations.localized_policy_versions import RequestPresignedURL
from ..operations.localized_policy_versions import RetrieveLocalizedPolicyVersions
from ..operations.localized_policy_versions import RetrieveSingleLocalizedPolicyVersion
from ..operations.localized_policy_versions import RetrieveSingleLocalizedPolicyVersion1
from ..operations.localized_policy_versions import SetDefaultPolicy
from ..operations.localized_policy_versions import UpdateLocalizedPolicyVersion


@same_doc_as(CreateLocalizedPolicyVersion)
def create_localized_policy_version(
    policy_version_id: str,
    body: Optional[CreateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreateLocalizedPolicyVersion.create(
        policy_version_id=policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateLocalizedPolicyVersion)
async def create_localized_policy_version_async(
    policy_version_id: str,
    body: Optional[CreateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = CreateLocalizedPolicyVersion.create(
        policy_version_id=policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RequestPresignedURL)
def request_presigned_url(
    localized_policy_version_id: str,
    body: Optional[UploadPolicyVersionAttachmentRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RequestPresignedURL.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RequestPresignedURL)
async def request_presigned_url_async(
    localized_policy_version_id: str,
    body: Optional[UploadPolicyVersionAttachmentRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RequestPresignedURL.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveLocalizedPolicyVersions)
def retrieve_localized_policy_versions(
    policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveLocalizedPolicyVersions.create(
        policy_version_id=policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveLocalizedPolicyVersions)
async def retrieve_localized_policy_versions_async(
    policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveLocalizedPolicyVersions.create(
        policy_version_id=policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveSingleLocalizedPolicyVersion)
def retrieve_single_localized_policy_version(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveSingleLocalizedPolicyVersion)
async def retrieve_single_localized_policy_version_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveSingleLocalizedPolicyVersion1)
def retrieve_single_localized_policy_version_1(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveSingleLocalizedPolicyVersion1.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveSingleLocalizedPolicyVersion1)
async def retrieve_single_localized_policy_version_1_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = RetrieveSingleLocalizedPolicyVersion1.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SetDefaultPolicy)
def set_default_policy(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SetDefaultPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SetDefaultPolicy)
async def set_default_policy_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = SetDefaultPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateLocalizedPolicyVersion)
def update_localized_policy_version(
    localized_policy_version_id: str,
    body: Optional[UpdateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateLocalizedPolicyVersion)
async def update_localized_policy_version_async(
    localized_policy_version_id: str,
    body: Optional[UpdateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    request = UpdateLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: accelbyte_cloud_py_codegen

# AccelByte Cloud Iam Service (5.16.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.accountcommon_jwt_ban_v3 import AccountcommonJWTBanV3
from ..models.accountcommon_namespace_role import AccountcommonNamespaceRole
from ..models.accountcommon_permission import AccountcommonPermission


class OauthmodelTokenResponse(Model):
    """Oauthmodel token response (oauthmodel.TokenResponse)

    Properties:
        access_token: (access_token) REQUIRED str

        bans: (bans) REQUIRED List[AccountcommonJWTBanV3]

        display_name: (display_name) REQUIRED str

        expires_in: (expires_in) REQUIRED int

        namespace: (namespace) REQUIRED str

        namespace_roles: (namespace_roles) REQUIRED List[AccountcommonNamespaceRole]

        permissions: (permissions) REQUIRED List[AccountcommonPermission]

        refresh_token: (refresh_token) REQUIRED str

        roles: (roles) REQUIRED List[str]

        token_type: (token_type) REQUIRED str

        user_id: (user_id) REQUIRED str

        is_comply: (is_comply) OPTIONAL bool

        jflgs: (jflgs) OPTIONAL int

        platform_id: (platform_id) OPTIONAL str

        platform_user_id: (platform_user_id) OPTIONAL str

        refresh_expires_in: (refresh_expires_in) OPTIONAL int
    """

    # region fields

    access_token: str  # REQUIRED
    bans: List[AccountcommonJWTBanV3]  # REQUIRED
    display_name: str  # REQUIRED
    expires_in: int  # REQUIRED
    namespace: str  # REQUIRED
    namespace_roles: List[AccountcommonNamespaceRole]  # REQUIRED
    permissions: List[AccountcommonPermission]  # REQUIRED
    refresh_token: str  # REQUIRED
    roles: List[str]  # REQUIRED
    token_type: str  # REQUIRED
    user_id: str  # REQUIRED
    is_comply: bool  # OPTIONAL
    jflgs: int  # OPTIONAL
    platform_id: str  # OPTIONAL
    platform_user_id: str  # OPTIONAL
    refresh_expires_in: int  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_access_token(self, value: str) -> OauthmodelTokenResponse:
        self.access_token = value
        return self

    def with_bans(self, value: List[AccountcommonJWTBanV3]) -> OauthmodelTokenResponse:
        self.bans = value
        return self

    def with_display_name(self, value: str) -> OauthmodelTokenResponse:
        self.display_name = value
        return self

    def with_expires_in(self, value: int) -> OauthmodelTokenResponse:
        self.expires_in = value
        return self

    def with_namespace(self, value: str) -> OauthmodelTokenResponse:
        self.namespace = value
        return self

    def with_namespace_roles(
        self, value: List[AccountcommonNamespaceRole]
    ) -> OauthmodelTokenResponse:
        self.namespace_roles = value
        return self

    def with_permissions(
        self, value: List[AccountcommonPermission]
    ) -> OauthmodelTokenResponse:
        self.permissions = value
        return self

    def with_refresh_token(self, value: str) -> OauthmodelTokenResponse:
        self.refresh_token = value
        return self

    def with_roles(self, value: List[str]) -> OauthmodelTokenResponse:
        self.roles = value
        return self

    def with_token_type(self, value: str) -> OauthmodelTokenResponse:
        self.token_type = value
        return self

    def with_user_id(self, value: str) -> OauthmodelTokenResponse:
        self.user_id = value
        return self

    def with_is_comply(self, value: bool) -> OauthmodelTokenResponse:
        self.is_comply = value
        return self

    def with_jflgs(self, value: int) -> OauthmodelTokenResponse:
        self.jflgs = value
        return self

    def with_platform_id(self, value: str) -> OauthmodelTokenResponse:
        self.platform_id = value
        return self

    def with_platform_user_id(self, value: str) -> OauthmodelTokenResponse:
        self.platform_user_id = value
        return self

    def with_refresh_expires_in(self, value: int) -> OauthmodelTokenResponse:
        self.refresh_expires_in = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "access_token"):
            result["access_token"] = str(self.access_token)
        elif include_empty:
            result["access_token"] = ""
        if hasattr(self, "bans"):
            result["bans"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.bans
            ]
        elif include_empty:
            result["bans"] = []
        if hasattr(self, "display_name"):
            result["display_name"] = str(self.display_name)
        elif include_empty:
            result["display_name"] = ""
        if hasattr(self, "expires_in"):
            result["expires_in"] = int(self.expires_in)
        elif include_empty:
            result["expires_in"] = 0
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "namespace_roles"):
            result["namespace_roles"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.namespace_roles
            ]
        elif include_empty:
            result["namespace_roles"] = []
        if hasattr(self, "permissions"):
            result["permissions"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.permissions
            ]
        elif include_empty:
            result["permissions"] = []
        if hasattr(self, "refresh_token"):
            result["refresh_token"] = str(self.refresh_token)
        elif include_empty:
            result["refresh_token"] = ""
        if hasattr(self, "roles"):
            result["roles"] = [str(i0) for i0 in self.roles]
        elif include_empty:
            result["roles"] = []
        if hasattr(self, "token_type"):
            result["token_type"] = str(self.token_type)
        elif include_empty:
            result["token_type"] = ""
        if hasattr(self, "user_id"):
            result["user_id"] = str(self.user_id)
        elif include_empty:
            result["user_id"] = ""
        if hasattr(self, "is_comply"):
            result["is_comply"] = bool(self.is_comply)
        elif include_empty:
            result["is_comply"] = False
        if hasattr(self, "jflgs"):
            result["jflgs"] = int(self.jflgs)
        elif include_empty:
            result["jflgs"] = 0
        if hasattr(self, "platform_id"):
            result["platform_id"] = str(self.platform_id)
        elif include_empty:
            result["platform_id"] = ""
        if hasattr(self, "platform_user_id"):
            result["platform_user_id"] = str(self.platform_user_id)
        elif include_empty:
            result["platform_user_id"] = ""
        if hasattr(self, "refresh_expires_in"):
            result["refresh_expires_in"] = int(self.refresh_expires_in)
        elif include_empty:
            result["refresh_expires_in"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        access_token: str,
        bans: List[AccountcommonJWTBanV3],
        display_name: str,
        expires_in: int,
        namespace: str,
        namespace_roles: List[AccountcommonNamespaceRole],
        permissions: List[AccountcommonPermission],
        refresh_token: str,
        roles: List[str],
        token_type: str,
        user_id: str,
        is_comply: Optional[bool] = None,
        jflgs: Optional[int] = None,
        platform_id: Optional[str] = None,
        platform_user_id: Optional[str] = None,
        refresh_expires_in: Optional[int] = None,
    ) -> OauthmodelTokenResponse:
        instance = cls()
        instance.access_token = access_token
        instance.bans = bans
        instance.display_name = display_name
        instance.expires_in = expires_in
        instance.namespace = namespace
        instance.namespace_roles = namespace_roles
        instance.permissions = permissions
        instance.refresh_token = refresh_token
        instance.roles = roles
        instance.token_type = token_type
        instance.user_id = user_id
        if is_comply is not None:
            instance.is_comply = is_comply
        if jflgs is not None:
            instance.jflgs = jflgs
        if platform_id is not None:
            instance.platform_id = platform_id
        if platform_user_id is not None:
            instance.platform_user_id = platform_user_id
        if refresh_expires_in is not None:
            instance.refresh_expires_in = refresh_expires_in
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> OauthmodelTokenResponse:
        instance = cls()
        if not dict_:
            return instance
        if "access_token" in dict_ and dict_["access_token"] is not None:
            instance.access_token = str(dict_["access_token"])
        elif include_empty:
            instance.access_token = ""
        if "bans" in dict_ and dict_["bans"] is not None:
            instance.bans = [
                AccountcommonJWTBanV3.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["bans"]
            ]
        elif include_empty:
            instance.bans = []
        if "display_name" in dict_ and dict_["display_name"] is not None:
            instance.display_name = str(dict_["display_name"])
        elif include_empty:
            instance.display_name = ""
        if "expires_in" in dict_ and dict_["expires_in"] is not None:
            instance.expires_in = int(dict_["expires_in"])
        elif include_empty:
            instance.expires_in = 0
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "namespace_roles" in dict_ and dict_["namespace_roles"] is not None:
            instance.namespace_roles = [
                AccountcommonNamespaceRole.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["namespace_roles"]
            ]
        elif include_empty:
            instance.namespace_roles = []
        if "permissions" in dict_ and dict_["permissions"] is not None:
            instance.permissions = [
                AccountcommonPermission.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["permissions"]
            ]
        elif include_empty:
            instance.permissions = []
        if "refresh_token" in dict_ and dict_["refresh_token"] is not None:
            instance.refresh_token = str(dict_["refresh_token"])
        elif include_empty:
            instance.refresh_token = ""
        if "roles" in dict_ and dict_["roles"] is not None:
            instance.roles = [str(i0) for i0 in dict_["roles"]]
        elif include_empty:
            instance.roles = []
        if "token_type" in dict_ and dict_["token_type"] is not None:
            instance.token_type = str(dict_["token_type"])
        elif include_empty:
            instance.token_type = ""
        if "user_id" in dict_ and dict_["user_id"] is not None:
            instance.user_id = str(dict_["user_id"])
        elif include_empty:
            instance.user_id = ""
        if "is_comply" in dict_ and dict_["is_comply"] is not None:
            instance.is_comply = bool(dict_["is_comply"])
        elif include_empty:
            instance.is_comply = False
        if "jflgs" in dict_ and dict_["jflgs"] is not None:
            instance.jflgs = int(dict_["jflgs"])
        elif include_empty:
            instance.jflgs = 0
        if "platform_id" in dict_ and dict_["platform_id"] is not None:
            instance.platform_id = str(dict_["platform_id"])
        elif include_empty:
            instance.platform_id = ""
        if "platform_user_id" in dict_ and dict_["platform_user_id"] is not None:
            instance.platform_user_id = str(dict_["platform_user_id"])
        elif include_empty:
            instance.platform_user_id = ""
        if "refresh_expires_in" in dict_ and dict_["refresh_expires_in"] is not None:
            instance.refresh_expires_in = int(dict_["refresh_expires_in"])
        elif include_empty:
            instance.refresh_expires_in = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, OauthmodelTokenResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[OauthmodelTokenResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        OauthmodelTokenResponse,
        List[OauthmodelTokenResponse],
        Dict[Any, OauthmodelTokenResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "access_token": "access_token",
            "bans": "bans",
            "display_name": "display_name",
            "expires_in": "expires_in",
            "namespace": "namespace",
            "namespace_roles": "namespace_roles",
            "permissions": "permissions",
            "refresh_token": "refresh_token",
            "roles": "roles",
            "token_type": "token_type",
            "user_id": "user_id",
            "is_comply": "is_comply",
            "jflgs": "jflgs",
            "platform_id": "platform_id",
            "platform_user_id": "platform_user_id",
            "refresh_expires_in": "refresh_expires_in",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "access_token": True,
            "bans": True,
            "display_name": True,
            "expires_in": True,
            "namespace": True,
            "namespace_roles": True,
            "permissions": True,
            "refresh_token": True,
            "roles": True,
            "token_type": True,
            "user_id": True,
            "is_comply": False,
            "jflgs": False,
            "platform_id": False,
            "platform_user_id": False,
            "refresh_expires_in": False,
        }

    # endregion static methods
